@@ -170,8 +170,7 @@ class Fusion:
         transformation.SetInterpolator(sitk.sitkBSpline)
         new_ct_img = transformation.Execute(ct_img) 
 
-
-        if mode == 'dict' : 
+        if self.mode == 'dict' : 
             return new_pet_img, new_ct_img
 
 
